@@ -78,6 +78,7 @@ test_that("BS_Geometric_Asian_Greeks is correct", {
           abs(Vals - Vals_fd))
   }
 
-  expect(max(error) < sqrt(epsilon))
+  expect(max(error) < sqrt(epsilon),
+  "Error in BS_Geometric_Asian_Greeks is too high")
 
 })
