@@ -87,7 +87,8 @@ test_that("implied volatility is correct", {
 
   }
 
-  expect(max(abs(option_price_test - option_price)) < 1e-06)
+  expect(max(abs(option_price_test - option_price)) < 1e-06,
+  "Implied_Volatility error is too high")
 
   # Checks if error is caught when the option price is infeasible low
   expect_error(Implied_Volatility(option_price = 10, exercise_price = 90))
